# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-26 12:12


import aparnik.contrib.users.models
from django.db import migrations
import django_enumfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0026_auto_20190526_1210'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='devicelogin',
            name='device_type_temp',
        ),
        migrations.AlterField(
            model_name='devicelogin',
            name='device_type',
            field=django_enumfield.db.fields.EnumField(default=0, enum=aparnik.contrib.users.models.DeviceType, verbose_name='Device Type'),
        ),
    ]
