# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('books', '0003_auto_20181026_1131'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='book',
            options={'verbose_name': '\\u06a9\\u062a\\u0627\\u0628', 'verbose_name_plural': '\\u06a9\\u062a\\u0627\\u0628 \\u0647\\u0627'},
        ),
        migrations.AlterModelOptions(
            name='booksegment',
            options={'verbose_name': '\\u0628\\u062e\\u0634 \\u06a9\\u062a\\u0627\\u0628', 'verbose_name_plural': '\\u0628\\u062e\\u0634 \\u06a9\\u062a\\u0627\\u0628 \\u0647\\u0627'},
        ),
        migrations.AlterModelOptions(
            name='publisher',
            options={'verbose_name': '\\u0645\\u0646\\u062a\\u0634\\u0631 \\u06a9\\u0646\\u0646\\u062f\\u0647', 'verbose_name_plural': '\\u0645\\u0646\\u062a\\u0634\\u0631 \\u06a9\\u0646\\u0646\\u062f\\u0647'},
        ),
        migrations.AlterModelOptions(
            name='writertranslator',
            options={'verbose_name': '\\u0645\\u062a\\u0631\\u062c\\u0645', 'verbose_name_plural': '\\u0645\\u062a\\u0631\\u062c\\u0645\\u06cc\\u0646'},
        ),
        migrations.AlterField(
            model_name='book',
            name='category_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='categories.Category', verbose_name='\\u062f\\u0633\\u062a\\u0647 \\u0628\\u0646\\u062f\\u06cc'),
        ),
        migrations.AlterField(
            model_name='book',
            name='published_date',
            field=models.DateTimeField(verbose_name='\\u062a\\u0627\\u0631\\u06cc\\u062e \\u0627\\u0646\\u062a\\u0634\\u0627\\u0631'),
        ),
        migrations.AlterField(
            model_name='book',
            name='publisher_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='books.Publisher', verbose_name='\\u0645\\u0646\\u062a\\u0634\\u0631 \\u06a9\\u0646\\u0646\\u062f\\u0647'),
        ),
        migrations.AlterField(
            model_name='book',
            name='sample_book',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='filefields.FileField', verbose_name='\\u06a9\\u062a\\u0627\\u0628 \\u0646\\u0645\\u0648\\u0646\\u0647'),
        ),
        migrations.AlterField(
            model_name='book',
            name='translators_obj',
            field=models.ManyToManyField(blank=True, related_name='library_translators', to='books.WriterTranslator', verbose_name='\\u0645\\u062a\\u0631\\u062c\\u0645\\u06cc\\u0646'),
        ),
        migrations.AlterField(
            model_name='book',
            name='writers_obj',
            field=models.ManyToManyField(related_name='library_writers', to='books.WriterTranslator', verbose_name='\\u0646\\u0648\\u06cc\\u0633\\u0646\\u062f\\u0647 \\u0647\\u0627'),
        ),
        migrations.AlterField(
            model_name='publisher',
            name='title',
            field=models.CharField(max_length=255, verbose_name='\\u0639\\u0646\\u0648\\u0627\\u0646'),
        ),
        migrations.AlterField(
            model_name='writertranslator',
            name='first_name',
            field=models.CharField(max_length=60, verbose_name='\\u0646\\u0627\\u0645'),
        ),
    ]
