# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-14 17:42


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('buttons', '0004_auto_20181125_2227'),
    ]

    operations = [
        migrations.AddField(
            model_name='button',
            name='title_color',
            field=models.CharField(blank=True, max_length=6, null=True, verbose_name='Title color'),
        ),
    ]
