# Generated by Django 2.2 on 2020-03-16 11:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0013_auto_20190615_1430'),
        ('courses', '0021_auto_20190714_1639'),
    ]

    operations = [
        migrations.CreateModel(
            name='CourseFileSegment',
            fields=[
                ('basesegment_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='segments.BaseSegment')),
            ],
            options={
                'verbose_name': 'Course File Segment',
                'verbose_name_plural': 'Course Files Segments',
            },
            bases=('segments.basesegment',),
        ),
    ]
