# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-02-15 19:16


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bankaccounts', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bankaccount',
            name='shaba_number',
            field=models.CharField(max_length=255, unique=True, verbose_name='Shaba Number'),
        ),
    ]
