# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-25 22:27


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contactus', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contactus',
            name='content',
            field=models.TextField(blank=True, null=True, verbose_name='Content'),
        ),
    ]
