# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-06-12 10:35


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0010_basemodel_visit_count'),
    ]

    operations = [
        migrations.AlterField(
            model_name='basemodel',
            name='review_average',
            field=models.FloatField(default=0.0, verbose_name='\\u0645\\u06cc\\u0627\\u0646\\u06af\\u06cc\\u0646 \\u0646\\u0638\\u0631\\u0627\\u062a'),
        ),
    ]
