# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-27 15:36


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0002_auto_20181026_1745'),
    ]

    operations = [
        migrations.AddField(
            model_name='basemodel',
            name='update_needed',
            field=models.BooleanField(default=False, verbose_name='Update needed'),
        ),
    ]
