# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 13:01


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='orderitem',
            managers=[
            ],
        ),
    ]
