# Generated by Django 2.2 on 2019-07-14 16:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0012_auto_20190701_0911'),
    ]

    operations = [
        migrations.AddField(
            model_name='filefield',
            name='file_external_url',
            field=models.URLField(blank=True, null=True, verbose_name='url'),
        ),
        migrations.AlterField(
            model_name='filefield',
            name='type',
            field=models.CharField(blank=True, choices=[('M', 'فیلم'), ('V', 'صدا'), ('P', 'پی دی اف'), ('I', 'عکس'), ('L', 'لینک')], max_length=1, null=True, verbose_name='نوع فایل'),
        ),
    ]
