# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-04-13 12:32


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('invitation', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='invite',
            options={'verbose_name': 'Invite', 'verbose_name_plural': 'Invites'},
        ),
    ]
