

            body{
                font-family: IRANSans, arial, sans-serif;
                background: #f7f7f7;
                margin: 0;
                direction: rtl;
                min-width: 768px;
            }
            * {
                outline:none !important;
                margin: 0;
                box-sizing: border-box;
                font-family: "iransans", arial, sans-serif;
            }
            *:hover, *:focus{
                outline: none !important;
            }
            a{
                text-decoration: none !important;
            }
            a:hover{
                color: unset;
            }
            textarea:focus,
            input:focus{
                box-shadow: none;
                outline: 0 none;
            }
            .homepage{
                min-width: 768px;
            }
            .homepage__titr{
                color: rgba(0, 0, 0, 0.86);
                font-size: 30px;
                font-weight: 300;
                line-height: 58px;
            }
            .homepage__description{
                color: rgba(0, 0, 0, 0.6);
                font-size: 14px;
                font-weight: 300;
                line-height: 25px;
            }
            .homepage__input-description{
                color: rgba(0, 0, 0, 0.86);
                font-size: 14px;
                font-weight: 300;
                line-height: 19px;
            }
            .homepage__couple-input-btn{
                height: 60px;
                display: flex;
                align-items: center;
                width: 100%;
            }
            .homepage__input{
                height: 60px;
                border-radius: 4px;
                border: 1px solid rgba(0, 0, 0, 0.2);
                background-color: #ffffff;
                padding: 20px 16px;
                color: rgba(0, 0, 0, 0.86);
                font-size: 14px;
                font-weight: 300;
            }
            .homepage__input::-webkit-input-placeholder {
                opacity: 0.3;
                color: rgba(0, 0, 0, 1);
                font-size: 14px;
                font-weight: 300;
            }

            .homepage__input:-moz-placeholder { /* Firefox 18- */
                opacity: 0.3;
                color: rgba(0, 0, 0, 1);
                font-size: 14px;
                font-weight: 300;
            }

            .homepage__input::-moz-placeholder {  /* Firefox 19+ */
                opacity: 0.3;
                color: rgba(0, 0, 0, 1);
                font-size: 14px;
                font-weight: 300;
            }

            .homepage__input:-ms-input-placeholder {
                color: rgba(0, 0, 0, 0.7);
                font-size: 14px;
                font-weight: 300;
            }
            .homepage__btn{
                height: 60px;
                border-radius: 4px;
                background-color: #ec0c6d;
                cursor: pointer;
            }
            .homepage__btn:hover{
                background: #aa004e;
            }
            .homepage__couple-input-btn .homepage__input{
                border-radius: 0 4px 4px 0;
            }
            .homepage__couple-input-btn .homepage__btn{
                border-radius: 4px 0 0 4px;
            }

            .homepage__btn p{
                height: 60px;
                line-height: 60px;
                text-align: center;
                color: white;
                font-size: 14px;
                font-weight: 500;
            }
            .pink-text{
                color: #ec0c6d;
            }
            a{
                cursor: pointer;
            }

            /* -------------Modal----------------*/

            .incomplete-order-modal .modal-body>div {
                position: absolute;
                top: 45%;
                left: 7%;
            }
            .incomplete-order-modal .modal-body>div p {
                margin-bottom: 0;
                font-size: 13px;
                color: #505050;
                font-weight: 300;
            }

            .btn-border-pink {
                border: 1px solid #EC008C !important;
            }

            /* --------------TopSection------------*/

            .search-section{
                width: 100%;
                max-width: 2000px;
                margin: auto;
                height: 728px;
                position: relative;
                                background-size: 2000px 800px;
                background-repeat: no-repeat;
                background-position: center center;
                text-align: center;
            }

            .search-section__top-layer{
                position: absolute;
                width: 100%;
                top: 0;
                height: 162px;
                background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.85) 0%, rgba(0, 0, 0, 0) 100%);
            }

            .search-section__bottom-layer{
                position: absolute;
                width: 100%;
                bottom: 0;
                height: 262px;
                background-image: linear-gradient(to top, rgba(0, 0, 0, 0.85) 0%, rgba(0, 0, 0, 0) 100%);
            }

            .search-section__header__wrapper{
                width: 100%;
                height: 75px;
                position: absolute;
                top: 0;
                z-index: 1;
            }

            .search-section__header{
                /*max-width: 1440px;*/
                height: 103px;
                padding: 28px 38px;
                margin: auto;
                display: flex;
                justify-content: space-between;
                align-items: center;
            }

            .header__order-status-container{
                height: 30px;
            }

            .header__order-status{
                list-style: none;
                font-size: 12px;
                font-weight: 500;
                color: white;
                display: flex;
                align-items: center;
            }
            .header__order-status a span{
                color: white;
                margin-right: 5px;
            }

            .header__order-status a{
                height: 30px;
                display: flex;
                align-items: center;
            }

            .hh_not-paid {
                display: inline-block;
                padding: 0;
                margin: 19px 0 19px 5px;
                color: #505050;
                position: relative;
            }

            .hh_not-paid a{
                display: inline-block;
            }

            .hh_not-paid a {
                line-height: 18px;
                font-size: 10px;
                border-radius: 5px;
                padding: 2px 10px;
                color: white;
                margin-right: 5px;
                border: 1px solid#eee;
            }
            .status-label-notif {
                background: #EC008C;
                width: 20px;
                height: 20px;
                position: absolute;
                left: -5px;
                top: -10px;
            }

            .status-label {
                display: inline;
                font-size: 12px;
                font-weight: 700;
                line-height: 20px;
                color: #fff;
                text-align: center;
                white-space: nowrap;
                border-radius: 50%;
            }

            .sidenav{
                height: 100vh;
                width: 0;
                position: relative;
                z-index: 1;
                top: -103px;
                right: 0;
                transition: 0.5s;
                overflow-x: hidden;
            }
            .sidenav .search-section__header__user{
                -webkit-filter: invert(30%) grayscale(100%) brightness(70%) contrast(4);
                filter: invert(30%) grayscale(100%) brightness(70%) contrast(4);
            }
            .closebtn{
                margin-left: 30px;
            }
            .closebtnImage{
                vertical-align: middle;
            }
            .user-menu{
                width: 100%;
                height: 100%;
                padding: 28px 38px;
                background-color: #f0f0f0;
                min-width: 300px;
            }
            .user-menu__links{
                margin-top: 25vh;
            }
            .user-menu__links a{
                color: rgba(0,0,0,0.86);
                display: block;
                text-align: center;
                font-size: 16px;
                margin: auto;
                margin-bottom: 15px;
                width: max-content;
            }
            .user-menu__links a:hover, .user-menu__links a:focus{
                color: rgba(0,0,0,0.86);
            }
            .language-sign{
                padding: 0 24px;
            }
            .language-sign a{
                font-size: 20px;
                line-height: 30px;
                color: white;
                font-family: "iransans", arial, sans-serif;
            }
            .language-sign a:hover, .language-sign a:focus{
                color: white;
            }
            .user-menu__top{
                height: 47px;
                display: flex;
                align-items: center;
                justify-content: flex-start;
            }

            .search-section__header__menu{
                display: flex;
                justify-content: space-between;
                align-items: center;
            }

            .search-section__header__logo{
                background-image:  url(/bundles/bodofoodfrontend/images/snappfood_logo.svg?v1542);
                /*background-position: -2px -0px;*/
                background-repeat: no-repeat;
                width: 207px; height: 47px;
                cursor: pointer;
                filter: brightness(0) invert(1);
            }
            .search-section__header__burgermenu{
                background-image:  url(/bundles/bodofoodfrontend/images/newhomepage/top-section-sprite.png?v1542);
                background-position: -2px -253px; width: 29px; height: 21px;
                margin-left: 24px;
                margin-top: 1px;
            }
            .search-section__header__user{
                width: max-content;
                height: 30px;
                border-radius: 15px;
                border: 1px solid rgba(255, 255, 255, 0.6);
                display: flex;
                justify-content: space-between;
                align-items: center;
                padding-right: 15px;
                padding-left: 15px;
            }
            .search-section__header__user__icon{
                background-image:  url(/bundles/bodofoodfrontend/images/newhomepage/top-section-sprite.png?v1542);
                background-position: -51px -253px; width: 14px; height: 14px;
                margin-left: 10px;
            }
            .search-section__header__user__name{
                font-size: 12px;
                font-weight: 500;
                color: white;
                max-width: 130px;
                text-overflow: ellipsis;
                white-space: nowrap;
                overflow: hidden;
            }
            .search-section__header__login{
                font-size: 12px;
                font-weight: 500;
                color: white;
                height: 27px;
                line-height: 27px;
                cursor: pointer;
            }
            .search-section__main{
                max-width: 1440px;
                height: 100%;
                margin: auto;
                padding-top: 227px;
                position: relative;
            }
            .search-section__right-layer{
                position: absolute;
                width: 150px;
                height: 100%;
                top: 0;
                right: 0;
                background-image: linear-gradient(to left, rgba(0, 0, 0, 1) 0%, rgba(0, 0, 0, 0) 100%);
            }
            .search-section__left-layer{
                position: absolute;
                width: 150px;
                top: 0;
                left: 0;
                height: 100%;
                background-image: linear-gradient(to right, rgba(0, 0, 0, 1) 0%, rgba(0, 0, 0, 0) 100%);
            }
            .search-section__main .address-container{
                width: 700px;
                top: 290px;
                right: calc(50% - 350px);
                margin-top: 0;
            }
            .search-box__address-list{
                overflow: auto;
                height: 150px;
            }

            .search-section__main__search-box {
                width: 700px;
                margin: auto;
                height: 137px;
                box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
                border-radius: 4px;
                border: 1px solid rgba(255, 255, 255, 0.1);
                background-color: rgba(0, 0, 0, 0.5);
                margin-bottom: 120px;
                padding: 23px 15px 15px 15px;
                display: none;

            }
            .active-search-box{
                display: block;
            }
            .area-search{
                width: 700px;
                height: 92px;
                margin: auto;
                padding: 15px;
                justify-content: space-between;
                display: flex;
            }
            .area-search-wrapper{
                width: 700px;
                height: 120px;
                box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
                border-radius: 4px;
                border: 1px solid rgba(255, 255, 255, 0.1);
                background-color: rgba(0, 0, 0, 0.5);
                margin: auto;
                margin-bottom: 120px;
                display: none;
            }
            .area-active-search-box{
                display: block;
            }
            .area-search input{
                width: 130px;
            }
            .area-search div{
                width: 100px;
            }
            .selectSearchByAddress{
                display: block;
                text-align: center;
                color: white;
                width: 160px;
                margin: auto;
                cursor: pointer;
            }

            .search-section__user-address{
                height: 30px;
                margin-bottom: 9px;
                display: flex;
                justify-content: flex-start;
            }
            .search-section__loc-icon{
                background-image:  url(/bundles/bodofoodfrontend/images/newhomepage/top-section-sprite.png?v1542);
                background-position: -33px -253px; width: 16px; height: 22px;
            }
            .search-section__user-address--selected{
                line-height: 30px;
                color: rgba(255, 255, 255, 0.86);
                font-size: 14px;
                width: 490px;
                margin-right: 17px;
                text-align: right;
                text-overflow: ellipsis;
                background-color: transparent;
                border: none;
            }
            .search-section__options--food{
                width: 270px;
            }
            .search-section__options--restaurant{
                width: 270px;
            }
            .search-section__main i {
                border: solid white;
                border-width: 0 3px 3px 0;
                display: inline-block;
                padding: 3px;
                width: 10px;
                height: 10px;
                opacity: 1;
                margin-right: 9px;
                margin-top: 8px;
            }
            .search-section__arrow-down{
                transform: rotate(45deg);
                -webkit-transform: rotate(45deg);
            }
            .search-section__options--search{
                width: 110px;
            }
            .search-section__options{
                height: 60px;
                display: flex;
                justify-content: space-between;
            }
            .search-section__main__services {
                display: flex;
                width: 700px;
                margin: auto;
                justify-content: space-between;
                align-items: center;
            }
            .search-section__main__services a{
                text-decoration: none;
            }
            .search-section__main__services__item{
                position: relative;
                cursor: pointer;
            }

            .search-section__main__services__item__image{
                background-image:  url(/bundles/bodofoodfrontend/images/newhomepage/top-section-sprite.png?v1542);
                width: 100px;
                height: 100px;
                box-shadow: 0 2px 4px rgba(0, 0, 0, 0.15);
                border: 6px solid #ffffff;
                border-radius: 50%;
                box-sizing: content-box;
            }

            .search-section__main__services__title{
                color: white;
                font-size: 14px;
                font-weight: 500;
                text-align: center;
                line-height: 30px;
            }
            .restaurant-service{
                background-position: -2px -151px;
            }
            .cafe-service{
                background-position: -2px -49px;
            }
            .confectionery-service{
                background-position: -104px -49px;
            }
            .supermarket-service{
                background-position: -104px -151px;
            }
            .search-section__main__services__number{
                position: absolute;
                width: 50px;
                height: 50px;
                box-shadow: 0 2px 4px rgba(0, 0, 0, 0.15);
                border: 1px solid #ec0c6d;
                background-color: #ffffff;
                border-radius: 50%;
                top: 69px;
                right: 9px;
            }
            .search-section__main__services__number p{
                line-height: 50px;
                color: #ec0c6d;
                font-weight: 700;
                font-size: 17px;
            }
            .address-container{
                display: none;
            }
            .modal{
                display: none;
            }

            /*-----------------AppSection------------------------*/

            .app-section-wrapper{
                width: 100%;
                height: 846px;
                padding-top: 80px;
            }
            .app-section{
                width: 956px;
                margin: auto;
                height: 616px;
                box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
                border-radius: 4px;
                background-color: #ffffff;
                display: flex;
            }

            .app-section__text{
                width: 60%;
                padding: 75px 40px 0 91px;
            }

            .app-section__text .homepage__titr{
                margin-bottom: 16px;
            }

            .app-section__text .homepage__description{
                margin-bottom: 58px;
                text-align: justify;
            }

            .app-section__text .homepage__input-description{
                margin-bottom: 10px;
            }

            .app-section__text .homepage__couple-input-btn{
                width: 423px;
            }
            .app-section__text .homepage__input{
                width: 287px;
            }
            .app-section__text .homepage__btn{
                width: 136px;
            }
            .app-section__text .homepage__couple-input-btn{
                margin-bottom: 42px;
            }
            .app-section__image{
                width: 40%;
                position: relative;
            }

            .app-section__image{
                position: relative;
                top: -76px;
            }

            .app-section__invalid-number, .app-section__success-msg, .app-section__fail-msg{
                display: none;
                font-size: 12px;
                position: relative;
                top: -34px;
            }
            .app-section__success-msg{
                color: #2a9134;
            }
            .app-section__invalid-number, .app-section__fail-msg{
                color: red;
            }
            .app-section__links{
                width: 423px;
                display: flex;
                justify-content: space-between;
                flex-wrap: wrap;
            }
            .category-section div:not(.fill-empty), .app-section__links div:not(.fill-empty){
                background-image: url(../img/app-categories-sprite.png);
            }
            .app-section__links div{
                width: 135px;
                height: 40px;
                margin-bottom: 11px;
                opacity: 0.5;
            }
            .input-error-newhomepage{
                  border: 1px solid red !important;
            }
            .subscribe-section__success-msg, .subscribe-section__fail-msg{
                display: none;
                font-size: 12px;
                position: relative;
                top: 15px;
            }
            .subscribe-section__success-msg{
                color: #2a9134;
            }
            .subscribe-section__fail-msg{
                color: red;
            }
            .error-animate {
                position: relative;
                -webkit-animation-name: example; /* Safari 4.0 - 8.0 */
                -webkit-animation-duration: 0.3s; /* Safari 4.0 - 8.0 */
                animation-name: example;
                animation-duration: 0.3s;
            }

                /* Safari 4.0 - 8.0 */
            @-webkit-keyframes example {
                0%   {left:0px;}
                25%  {left:2px;}
                50%  { left:-2px;}
                75%  { left:2px;}
                100% { left:-2px;}
            }

                /* Standard syntax */
            @keyframes example {
                0%   {left:0px;}
                25%  {left:2px;}
                50%  {left:-2px;}
                75%  {left:2px;}
                100% {left:-2px;}
            }
	    .app-section__links div:hover{
		opacity: 1;
	    }
            .android { background-position: -0px -1335px;}
	    .appstore { background-position: -0px -1375px;}
	    .cafebazaar { background-position: -0px -1415px;}
	    .googleplay { background-position: -0px -1455px;}
	    .ios { background-position: -0px -1495px;}
	    .sibapp { background-position: -0px -1535px;}
            @media screen and (max-width: 999px) {
                .app-section{
                    width: 730px;
                    margin: auto;
                    height: 440px;
                }
                .app-section__text{
                    padding: 20px 30px 0 10px;
                }
                .mobileImage{
                    width: 250px;
                }
                .app-section__text .homepage__description{
                    margin-bottom: 25px;
                }
                .app-section__text .homepage__couple-input-btn{
                    margin-bottom: 35px;
                }
                .app-section__links div{
                    margin-bottom: 5px;
                }
                .app-section__image {
                    top: -40px;
                    right: 30px;
                }
                .app-section-wrapper{
                    padding-top: 80px;
                    height: 600px;
                }
            }
            @media screen and (max-width: 767px) {
                .app-section__image{
                    right: 18px;
                }
            }
            .ramadan-modal{
                position: fixed;
                width: 500px;
                height: 550px;
                background-color: black;
                top: 50%;
                left: 50%;
                transform: translate(-50%, -50%);
                border-radius: 15px;
                z-index: 2;
            }
            .ramadan-cta{
                width: 420px;
                background-color: white;
                margin: auto;
                padding: 20px;
                text-align: center;
                border-radius: 15px;
            }
            .ramadan-modal img{
                width: 100%;
                height: auto;
                display: block;
                border-radius: 15px;
            }
            .ramadan-cta > p{
                font-size: 14px;
                line-height: 26px;
                color: rgba(0, 0, 0, 0.86);
                margin-bottom: 15px;
            }
            .ramadan-modal p span{
                font-weight: bold;
            }
            .ramadan-modal button{
                outline: none;
                border: none;
                width: 60%;
                background-color: #ec0c6d;
                height: 40px;
                line-height: 40px;
                text-align: center;
                color: white;
                border-radius: 15px;
                cursor: pointer;
            }
            .ramadan-close img{
                width: 20px;
                display: inline-block;
            }
            .ramadan-close {
                position: absolute;
                top: 10px;
                left: 10px;
                cursor: pointer;
            }