# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 16:17


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filefield',
            name='size',
            field=models.IntegerField(default=0, verbose_name='File Size'),
        ),
    ]
