# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='basemodel',
            options={'ordering': ['-created_at'], 'verbose_name': '\\u0645\\u062f\\u0644 \\u067e\\u0627\\u06cc\\u0647', 'verbose_name_plural': '\\u0645\\u062f\\u0644 \\u0647\\u0627\\u06cc \\u067e\\u0627\\u06cc\\u0647'},
        ),
        migrations.AlterField(
            model_name='basemodel',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='\\u0633\\u0627\\u062e\\u062a\\u0647 \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
        migrations.AlterField(
            model_name='basemodel',
            name='review_average',
            field=models.FloatField(blank=True, null=True, verbose_name='\\u0645\\u06cc\\u0627\\u0646\\u06af\\u06cc\\u0646 \\u0646\\u0638\\u0631\\u0627\\u062a'),
        ),
        migrations.AlterField(
            model_name='basemodel',
            name='update_at',
            field=models.DateTimeField(auto_now=True, verbose_name='\\u0628\\u0631\\u0648\\u0632\\u0631\\u0633\\u0627\\u0646\\u06cc \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
    ]
