# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0003_auto_20181026_1131'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='basecourse',
            options={'verbose_name': '\\u062f\\u0648\\u0631\\u0647 \\u067e\\u0627\\u06cc\\u0647', 'verbose_name_plural': '\\u062f\\u0648\\u0631\\u0647 \\u067e\\u0627\\u06cc\\u0647'},
        ),
        migrations.AlterModelOptions(
            name='course',
            options={'verbose_name': '\\u062f\\u0648\\u0631\\u0647', 'verbose_name_plural': '\\u062f\\u0648\\u0631\\u0647'},
        ),
        migrations.AlterModelOptions(
            name='coursefile',
            options={'verbose_name': '\\u0641\\u0627\\u06cc\\u0644', 'verbose_name_plural': '\\u0641\\u0627\\u06cc\\u0644 \\u0647\\u0627'},
        ),
        migrations.AlterModelOptions(
            name='coursesegment',
            options={'verbose_name': '\\u0628\\u062e\\u0634 \\u062f\\u0648\\u0631\\u0647', 'verbose_name_plural': '\\u0628\\u062e\\u0634 \\u062f\\u0648\\u0631\\u0647 \\u0647\\u0627'},
        ),
        migrations.AlterModelOptions(
            name='coursesummary',
            options={'verbose_name': '\\u062e\\u0644\\u0627\\u0635\\u0647 \\u062f\\u0648\\u0631\\u0647', 'verbose_name_plural': '\\u062e\\u0644\\u0627\\u0635\\u0647 \\u062f\\u0648\\u0631\\u0647'},
        ),
        migrations.AlterField(
            model_name='basecourse',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='\\u062a\\u0648\\u0636\\u06cc\\u062d\\u0627\\u062a'),
        ),
        migrations.AlterField(
            model_name='course',
            name='banner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='course_banner', to='filefields.FileField', verbose_name='\\u0628\\u0646\\u0631'),
        ),
        migrations.AlterField(
            model_name='course',
            name='category_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='categories.Category', verbose_name='\\u062f\\u0633\\u062a\\u0647 \\u0628\\u0646\\u062f\\u06cc'),
        ),
        migrations.AlterField(
            model_name='course',
            name='cover',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='course_cover', to='filefields.FileField', verbose_name='\\u062a\\u0635\\u0648\\u06cc\\u0631 \\u062c\\u0644\\u062f'),
        ),
        migrations.AlterField(
            model_name='course',
            name='dependency_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dependency', to='courses.Course', verbose_name='\\u0648\\u0627\\u0628\\u0633\\u062a\\u06af\\u06cc'),
        ),
        migrations.AlterField(
            model_name='course',
            name='is_free',
            field=models.BooleanField(default=False, verbose_name='\\u0631\\u0627\\u06cc\\u06af\\u0627\\u0646\\u061f'),
        ),
        migrations.AlterField(
            model_name='course',
            name='parent_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='courses.Course', verbose_name='\\u0648\\u0627\\u0644\\u062f'),
        ),
        migrations.AlterField(
            model_name='course',
            name='publish_date',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='\\u062a\\u0627\\u0631\\u06cc\\u062e \\u0627\\u0646\\u062a\\u0634\\u0627\\u0631'),
        ),
        migrations.AlterField(
            model_name='course',
            name='publish_day',
            field=models.CharField(blank=True, choices=[('1', '\\u0634\\u0646\\u0628\\u0647'), ('2', '\\u06cc\\u06a9\\u0634\\u0646\\u0628\\u0647'), ('3', '\\u062f\\u0648\\u0634\\u0646\\u0628\\u0647'), ('4', '\\u0633\\u0647 \\u0634\\u0646\\u0628\\u0647'), ('5', '\\u0686\\u0647\\u0627\\u0631\\u0634\\u0646\\u0628\\u0647'), ('6', '\\u067e\\u0646\\u062c \\u0634\\u0646\\u0628\\u0647'), ('7', '\\u062c\\u0645\\u0639\\u0647')], max_length=1, null=True, verbose_name='\\u0631\\u0648\\u0632'),
        ),
        migrations.AlterField(
            model_name='course',
            name='publish_month',
            field=models.CharField(blank=True, choices=[('1', '\\u0641\\u0631\\u0648\\u0631\\u062f\\u06cc\\u0646'), ('2', '\\u0627\\u0631\\u062f\\u06cc\\u0628\\u0647\\u0634\\u062a'), ('3', '\\u062e\\u0631\\u062f\\u0627\\u062f'), ('4', '\\u062a\\u06cc\\u0631'), ('5', '\\u0645\\u0631\\u062f\\u0627\\u062f'), ('6', '\\u0634\\u0647\\u0631\\u06cc\\u0648\\u0631'), ('7', '\\u0645\\u0647\\u0631'), ('8', '\\u0622\\u0628\\u0627\\u0646'), ('9', '\\u0622\\u0630\\u0631'), ('10', '\\u062f\\u06cc'), ('11', '\\u0628\\u0647\\u0645\\u0646'), ('12', '\\u0627\\u0633\\u0641\\u0646\\u062f')], max_length=2, null=True, verbose_name='\\u0645\\u0627\\u0647'),
        ),
        migrations.AlterField(
            model_name='course',
            name='publish_week',
            field=models.CharField(blank=True, choices=[('1', '1'), ('2', '2'), ('3', '3'), ('4', '4')], max_length=1, null=True, verbose_name='\\u0647\\u0641\\u062a\\u0647'),
        ),
        migrations.AlterField(
            model_name='course',
            name='sort',
            field=models.IntegerField(default=0, verbose_name='\\u0645\\u0631\\u062a\\u0628 \\u0633\\u0627\\u0632\\u06cc'),
        ),
        migrations.AlterField(
            model_name='course',
            name='teacher_obj',
            field=models.ManyToManyField(blank=True, to='teachers.Teacher', verbose_name='\\u0645\\u062f\\u0631\\u0633\\u06cc\\u0646'),
        ),
        migrations.AlterField(
            model_name='coursefile',
            name='course_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='courses.Course', verbose_name='\\u062f\\u0648\\u0631\\u0647'),
        ),
        migrations.AlterField(
            model_name='coursefile',
            name='sort',
            field=models.IntegerField(default=0, verbose_name='\\u0645\\u0631\\u062a\\u0628 \\u0633\\u0627\\u0632\\u06cc'),
        ),
        migrations.AlterField(
            model_name='coursesummary',
            name='course',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='total_times', to='courses.BaseCourse', verbose_name='\\u062f\\u0648\\u0631\\u0647'),
        ),
        migrations.AlterField(
            model_name='coursesummary',
            name='file_count',
            field=models.PositiveIntegerField(default=0, verbose_name='\\u062a\\u0639\\u062f\\u0627\\u062f \\u0641\\u0627\\u06cc\\u0644 \\u0647\\u0627'),
        ),
        migrations.AlterField(
            model_name='coursesummary',
            name='file_count_preview',
            field=models.PositiveIntegerField(default=0, verbose_name='\\u062a\\u0639\\u062f\\u0627\\u062f \\u0641\\u0627\\u06cc\\u0644 \\u0647\\u0627\\u06cc \\u067e\\u06cc\\u0634 \\u0646\\u0645\\u0627\\u06cc\\u0634'),
        ),
        migrations.AlterField(
            model_name='coursesummary',
            name='type',
            field=models.CharField(choices=[('M', '\\u0641\\u06cc\\u0644\\u0645'), ('V', '\\u0635\\u062f\\u0627'), ('P', '\\u067e\\u06cc \\u062f\\u06cc \\u0627\\u0641'), ('I', '\\u0639\\u06a9\\u0633')], max_length=1, verbose_name='\\u0646\\u0648\\u0639'),
        ),
    ]
