# Generated by Django 2.2 on 2020-02-14 18:03

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('chats', '0003_auto_20200210_1451'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChatMessageNotification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('update_at', models.DateTimeField(auto_now=True)),
                ('is_read', models.BooleanField(default=False, verbose_name='Is read')),
                ('chat_message', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='message_notifications', to='chats.ChatSessionMessage')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
