# Generated by Django 2.2 on 2020-01-05 15:26

import aparnik.contrib.chats.models
from django.db import migrations
import django_enumfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('chats', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chatsession',
            name='type',
            field=django_enumfield.db.fields.EnumField(default=1, enum=aparnik.contrib.chats.models.ChatSessionTypeEnum, verbose_name='Type'),
        ),
    ]
