# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-03 22:33


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('progresses', '0002_progresssummary'),
    ]

    operations = [
        migrations.AlterField(
            model_name='progresses',
            name='file_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='courses.CourseFile', verbose_name='File'),
        ),
    ]
