# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-25 19:37


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filefields', '0004_filefield_title'),
        ('basemodels', '0004_auto_20181103_2233'),
        ('segments', '0002_auto_20181026_1745'),
    ]

    operations = [
        migrations.CreateModel(
            name='Button',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('title', models.CharField(blank=True, max_length=255, null=True, verbose_name='\\u0639\\u0646\\u0648\\u0627\\u0646')),
                ('icon', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='filefields.FileField', verbose_name='\\u0622\\u06cc\\u06a9\\u0646')),
                ('model_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='button_model', to='basemodels.BaseModel', verbose_name='\\u0686\\u0647 \\u0686\\u06cc\\u0632 \\u0631\\u0627 \\u0646\\u0645\\u0627\\u06cc\\u0634 \\u062f\\u0647\\u062f\\u061f')),
            ],
            options={
                'verbose_name': 'Button',
                'manager_inheritance_from_future': True,
                'verbose_name_plural': 'Buttons',
            },
            bases=('basemodels.basemodel',),
        ),
        migrations.CreateModel(
            name='ButtonSegment',
            fields=[
                ('basesegment_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='segments.BaseSegment')),
            ],
            options={
                'verbose_name': 'Button Segment',
                'manager_inheritance_from_future': True,
                'verbose_name_plural': 'Button Segments',
            },
            bases=('segments.basesegment',),
        ),
    ]
