# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-17 16:51


import aparnik.contrib.notifications.models
from django.db import migrations
import django_enumfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0003_auto_20190517_1651'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='notification',
            name='is_for_all_users',
        ),
        migrations.AlterField(
            model_name='notification',
            name='notification_send_type',
            field=django_enumfield.db.fields.EnumField(default=2, enum=aparnik.contrib.notifications.models.NotificationType, verbose_name='Notification send type'),
        ),
    ]
