# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-26 10:43


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0022_user_company_economical_number'),
    ]

    operations = [
        migrations.RenameField(
            model_name='devicelogin',
            old_name='device_type',
            new_name='device_type_temp',
        ),
    ]
