# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-03-19 17:53


import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0019_auto_20190319_1747'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='username_mention',
            field=models.CharField(default='a', max_length=100, unique=True, validators=[django.core.validators.RegexValidator(code='invalid_username', message='Username must be Alphanumeric', regex='^[a-zA-Z_\\-0-9]+$')], verbose_name='Username for mention'),
        ),
    ]
