# Generated by Django 2.2 on 2020-02-28 10:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0009_auto_20190821_1543'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='type',
            field=models.CharField(choices=[('i', 'اطلاعات'), ('ch', 'Chat'), ('s', 'موفقیت'), ('w', 'هشدار'), ('e', 'خطا')], max_length=2, verbose_name='Type'),
        ),
    ]
