# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-03-15 17:17


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bankaccounts', '0002_auto_20190215_1916'),
    ]

    operations = [
        migrations.AddField(
            model_name='bankaccount',
            name='card_number',
            field=models.CharField(default="1111111111111111", max_length=16, verbose_name='Card Number'),
            preserve_default=False,
        ),
    ]
