# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-02 15:42


import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0009_auto_20181130_2025'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='product',
            name='has_permit_use_aparnik_bon_value',
        ),
        migrations.AddField(
            model_name='product',
            name='has_permit_use_wallet_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', validators=[django.core.validators.MaxValueValidator(1), django.core.validators.MinValueValidator(-1)], verbose_name='Has Permit use wallet'),
        ),
        migrations.AddField(
            model_name='product',
            name='maximum_use_aparnik_bon_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', verbose_name='Maximum use aparnik bon'),
        ),
        migrations.AlterField(
            model_name='product',
            name='aparnik_bon_return_expire_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', verbose_name='Bon Return Expire ( Hours )'),
        ),
        migrations.AlterField(
            model_name='product',
            name='aparnik_bon_return_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', verbose_name='Bon Return'),
        ),
    ]
