# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bookmarks', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bookmark',
            options={'verbose_name': '\\u0628\\u0648\\u06a9\\u0645\\u0627\\u0631\\u06a9', 'verbose_name_plural': '\\u0628\\u0648\\u06a9\\u0645\\u0627\\u0631\\u06a9 \\u0647\\u0627'},
        ),
        migrations.AlterField(
            model_name='bookmark',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='\\u0633\\u0627\\u062e\\u062a\\u0647 \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
        migrations.AlterField(
            model_name='bookmark',
            name='model_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bookmark_obj', to='basemodels.BaseModel', verbose_name='\\u0686\\u0647 \\u0686\\u06cc\\u0632 \\u0631\\u0627 \\u0646\\u0645\\u0627\\u06cc\\u0634 \\u062f\\u0647\\u062f\\u061f'),
        ),
        migrations.AlterField(
            model_name='bookmark',
            name='update_at',
            field=models.DateTimeField(auto_now=True, verbose_name='\\u0628\\u0631\\u0648\\u0632\\u0631\\u0633\\u0627\\u0646\\u06cc \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
    ]
